@@ -1,7 +1,7 @@
 import logging as log
 import json
 import threading
-from typing import Optional
+from typing import Optional, Union
 
 import requests
 from requests import Response
@@ -14,7 +14,7 @@ __all__ = (
 )
 
 
-def handle_api_response(resp: requests.Response) -> Response | dict:
+def handle_api_response(resp: requests.Response) -> Union[Response, dict]:
     resp.raise_for_status()  # Raise errors
     try:
         body: json = resp.json()
@@ -32,9 +32,9 @@ class HttpClient:
         self.is_bot = bot
         self.headers = {'Authorization': f'{"Bot " if bot else ""}{self._token}'}
 
-    def requests(self, method: str, path: str, *, data: Optional[dict | str] = None, headers: Optional[dict] = None,
+    def requests(self, method: str, path: str, *, data: Union[str, dict, None] = None, headers: Optional[dict] = None,
                  threads: bool = False,
-                 **kwargs) -> Optional[Response | dict]:
+                 **kwargs) -> Union[Response, dict, None]:
         """
         Send a request using self api\n
         :param method: :class:`str`
@@ -62,8 +62,8 @@ class HttpClient:
             return self.send(method, url, data, headers, **kwargs)
 
     @staticmethod
-    def send(method: str, url: str, data: Optional[dict | str], headers: Optional[dict],
-             **kwargs) -> Response | dict | bool:
+    def send(method: str, url: str, data: Union[str, dict, None], headers: Optional[dict],
+             **kwargs) -> Union[Response, dict, bool]:
         try:
             if method == "GET":
                 resp = requests.get(url, headers=headers, **kwargs)
