@@ -3,7 +3,7 @@ import logging as log
 import threading
 import types
 from inspect import signature
-from typing import Callable, Literal
+from typing import Callable, Literal, Union
 from dataclasses import dataclass
 
 from discord_gateway.api import HttpClient
@@ -29,7 +29,7 @@ class GatewayEvent:  # Store events
     type: str = 'global'
 
     def get_args(self, msg: GatewayMessage, token: str, user: SimpleNamespace,
-                 is_bot: bool = True) -> DiscordMessage | object | Literal[False]:
+                 is_bot: bool = True) -> Union[DiscordMessage, object, Literal[False]]:
         """
         Extracts arguments before passing to an event\n
         :param msg: :class:`GatewayMessage`
@@ -54,7 +54,7 @@ class GatewayEvent:  # Store events
         else:
             return self.extract_args(msg).data if args else args
 
-    def extract_args(self, msg: GatewayMessage) -> GatewayMessage | Literal[False]:
+    def extract_args(self, msg: GatewayMessage) -> Union[GatewayMessage, Literal[False]]:
         if len(signature(self.function).parameters):
             return msg
         else:
