@@ -1,10 +1,11 @@
-from typing import Optional, Callable, Any
+from typing import Optional, Callable, Any, Union
 
 from requests import Response
 
 from discord_gateway.discord_objects import DiscordChannel, DiscordGuild
 from discord_gateway.discord_user import DiscordUser
-from discord_gateway.gateway_handler import Gateway, GatewayMessage
+from discord_gateway.gateway_handler import Gateway
+from gateway import GatewayMessage
 from discord_gateway.api import HttpClient
 from types import SimpleNamespace
 from discord_gateway.constants import Intents
@@ -67,7 +68,7 @@ class GatewayBot(Gateway):
         """
         return DiscordGuild(guild_id, api=self.api)
 
-    async def dms(self) -> Response | dict:
+    async def dms(self) -> Union[Response, dict]:
         """
         Get open dms of bot\n
         :return: :class:`Union[Response, dict]`
@@ -90,7 +91,7 @@ class GatewayBot(Gateway):
         return DiscordUser(self.api.requests(method='POST', path=f'/users/@me/channels', json={"recipients": [user_id]},
                                              headers=headers), self.api)
 
-    async def join(self, server_invite: str) -> Response | dict:
+    async def join(self, server_invite: str) -> Union[Response, dict]:
         """
         Join a guild by invite {SelfBot only}\n
         :param server_invite: :class:`str`
@@ -108,7 +109,7 @@ class GatewayBot(Gateway):
         """
         self.api.requests(method='DELETE', path=f'/users/@me/guilds/{guild_id}')
 
-    async def create_group_chat(self, ids: list[str]) -> Response | dict:
+    async def create_group_chat(self, ids: list[str]) -> Union[Response, dict]:
         """
         Creates a group chat with members {SelfBot only}\n
         :param ids: :class:`list[str]`
